@@ -1,4 +1,4 @@
-from abc import ABC, abstractmethod
+from abc import ABC
 from datetime import date, datetime
 from typing import (
     Any,
@@ -19,10 +19,8 @@ import attr
 from inter_rao_energosbyt.actions import (
     DataMapping,
 )
-from inter_rao_energosbyt.actions.sql import (
-    ACTION_SQL,
-)
 from inter_rao_energosbyt.actions._bases import ResultCodeMappingBase
+from inter_rao_energosbyt.actions.sql import ACTION_SQL
 from inter_rao_energosbyt.converters import (
     conv_float_optional,
     conv_float_substitute,
@@ -339,11 +337,8 @@ class Invoice(DataMapping):
         return await api.async_action_map(cls, ACTION_SQL, proxy, data)
 
     id_korr = attr.ib(converter=int, type=int)
-    data_common = attr.ib(type=Tuple[InvoiceDataEntry], converter=_converter__data_common)
-    data_detail = attr.ib(
-        type=List[List[InvoiceDataEntry]],
-        converter=_converter__data_detail,
-    )
+    data_common: Tuple[InvoiceDataEntry] = attr.ib(converter=_converter__data_common)
+    data_detail: List[List[InvoiceDataEntry]] = attr.ib(converter=_converter__data_detail)
     dt_period: str = attr.ib(converter=str)
     sm_total: float = attr.ib(converter=conv_float_substitute, default=0.0)
 
@@ -828,7 +823,7 @@ IndicationType = Union[SupportsInt, SupportsFloat, SupportsInt]
 
 
 @attr.s(kw_only=True, slots=True, frozen=True)
-class CalcCharge(DataMapping):
+class CalcCharge(ResultCodeMappingBase):
     returns_single: ClassVar[bool] = True
 
     @classmethod
@@ -890,7 +885,7 @@ class CalcCharge(DataMapping):
 
 
 @attr.s(kw_only=True, frozen=True, slots=True)
-class SaveIndications(DataMapping):
+class SaveIndications(ResultCodeMappingBase):
     @classmethod
     async def async_request(
         cls,
@@ -900,6 +895,7 @@ class SaveIndications(DataMapping):
         data: Optional[Mapping[str, Any]] = None,
         query: str = "SaveIndications",
         pr_flat_meter: Any = None,
+        nn_phone: Any = None,
         vl_t1: Any = None,
         vl_t2: Any = None,
         vl_t3: Any = None,
@@ -912,6 +908,7 @@ class SaveIndications(DataMapping):
         :param data: Additional request data
         :param query: Proxy query name (default: query name associated with query class)
         :param pr_flat_meter: Query data element (type(s): int, assumed required)
+        :param nn_phone: Query data element (type(s): str, assumed required)
         :param vl_t1: Query data element (type(s): int, assumed required)
         :param vl_t2: Query data element (type(s): int, optional)
         :param vl_t3: Query data element (type(s): int, optional)
@@ -923,6 +920,9 @@ class SaveIndications(DataMapping):
         if data.get("pr_flat_meter") is None and pr_flat_meter is not None:
             data["pr_flat_meter"] = pr_flat_meter
 
+        if data.get("nn_phone") is None and nn_phone is not None:
+            data["nn_phone"] = nn_phone
+
         if data.get("vl_t1") is None and vl_t1 is not None:
             data["vl_t1"] = vl_t1
 
