@@ -8,6 +8,7 @@ __all__ = (
 
 import logging
 from datetime import tzinfo
+from typing import ClassVar
 
 import pytz
 
@@ -31,10 +32,11 @@ class OryolEnergosbytAPI(BaseEnergosbytAPI):
 
     LOGGER = logging.getLogger(__name__)
 
-    BASE_URL: str = "https://my.interrao-orel.ru"
-    AUTH_URL: str = BASE_URL + "/auth_url"
-    REQUEST_URL: str = BASE_URL + "/gate_lkcomu_orl"
-    ACCOUNT_URL: str = BASE_URL + "/accounts"
+    BASE_URL: ClassVar[str] = "https://my.interrao-orel.ru"
+    AUTH_URL: ClassVar[str] = BASE_URL + "/auth_url"
+    REQUEST_URL: ClassVar[str] = BASE_URL + "/gate_lkcomu_orl"
+    ACCOUNT_URL: ClassVar[str] = BASE_URL + "/accounts"
+    APP_VERSION: ClassVar[str] = "1.26.0"
 
 
 @OryolEnergosbytAPI.register_supported_account(
